@@ -20,7 +20,7 @@
 #include <kdialogbase.h>
 #include <tqstringlist.h>
 
-class KListView;
+class TDEListView;
 
 /**
   *@author Holger Danielsson
@@ -31,7 +31,7 @@ namespace KileDialog
 	class Clean : public KDialogBase
 	{
 	Q_OBJECT
-  TQ_OBJECT
+  
 	
 	public: 
 		Clean(TQWidget *parent, const TQString & filename, const TQStringList &extlist);
@@ -39,7 +39,7 @@ namespace KileDialog
 		const TQStringList & getCleanlist();
 	
 	private:
-		KListView		*listview;   
+		TDEListView		*listview;   
 		TQStringList	m_extlist;
 	};
 }
