@@ -360,7 +360,7 @@ int KileMultiTabBarInternal::appendTab(const TQPixmap &pic ,int id,const TQStrin
 	tab->installEventFilter(this);
 	tab->showActiveTabText(m_showActiveTabTexts);
 
-	if (m_style==KileMultiTabBar::KONTQSBC)
+	if (m_style==KileMultiTabBar::KONQSBC)
 	{
 		if (m_expandedTabSize<tab->neededSize()) {
 			m_expandedTabSize=tab->neededSize();
@@ -437,7 +437,7 @@ void KileMultiTabBarButton::setText(const TQString& text)
 {
 	TQString s = text;
 	s = s.replace("&", TQString()); // we do not allow accelerators to be set
-                                       // This is a little hack to avoid KAcceleratorManager
+                                       // This is a little hack to avoid TDEAcceleratorManager
                                        // provide us with accelerators as the class name of the
                                        // widget is no longer KMultiTabBar.
 	TQPushButton::setText(s);
@@ -584,7 +584,7 @@ void KileMultiTabBarTab::setState(bool b)
 
 void KileMultiTabBarTab::updateState()
 {
-	if (m_style!=KileMultiTabBar::KONTQSBC) {
+	if (m_style!=KileMultiTabBar::KONQSBC) {
 		if ((m_style==KileMultiTabBar::KDEV3) || (m_style==KileMultiTabBar::KDEV3ICON) || (isOn())) {
 			TQPushButton::setText(m_text);
 		} else {
@@ -644,7 +644,7 @@ void KileMultiTabBarTab::drawButtonLabel(TQPainter *p) {
 }
 void KileMultiTabBarTab::drawButton(TQPainter *paint)
 {
-	if (m_style!=KileMultiTabBar::KONTQSBC) drawButtonStyled(paint);
+	if (m_style!=KileMultiTabBar::KONQSBC) drawButtonStyled(paint);
 	else  drawButtonClassic(paint);
 }
 
@@ -876,7 +876,7 @@ KileMultiTabBar::KileMultiTabBar(KileMultiTabBarMode bm, TQWidget *parent,const
 	setPosition((bm==KileMultiTabBar::Vertical)?KileMultiTabBar::Right:KileMultiTabBar::Bottom);
 	setStyle(VSNET);
 	//	setStyle(KDEV3);
-	//setStyle(KONTQSBC);
+	//setStyle(KONQSBC);
 	m_l->insertWidget(0,m_internal);
 	m_l->insertWidget(0,m_btnTabSep=new TQFrame(this));
 	m_btnTabSep->setFixedHeight(4);
@@ -892,7 +892,7 @@ KileMultiTabBar::~KileMultiTabBar() {
 
 /*int KileMultiTabBar::insertButton(TQPixmap pic,int id ,const TQString&)
 {
-  (new KToolbarButton(pic,id,m_internal))->show();
+  (new TDEToolbarButton(pic,id,m_internal))->show();
   return 0;
 }*/
 
