@@ -19,10 +19,10 @@
 
 #include <tqheader.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kurl.h>
 #include <krun.h>
 #include <kmimetype.h>
@@ -101,7 +101,7 @@ int KileProjectViewItem::compare(TQListViewItem * i, int col, bool ascending) co
 /*
  * KileProjectView
  */
-KileProjectView::KileProjectView(TQWidget *parent, KileInfo *ki) : KListView(parent), m_ki(ki), m_nProjects(0), m_toggle(0)
+KileProjectView::KileProjectView(TQWidget *parent, KileInfo *ki) : TDEListView(parent), m_ki(ki), m_nProjects(0), m_toggle(0)
 {
 	addColumn(i18n("Files & Projects"),-1);
 	addColumn(i18n("Include in Archive"),10);
@@ -111,11 +111,11 @@ KileProjectView::KileProjectView(TQWidget *parent, KileInfo *ki) : KListView(par
 	setRootIsDecorated(true);
 	setAllColumnsShowFocus(true);
 	setFullWidth(true);
-	setSelectionModeExt(KListView::NoSelection);
+	setSelectionModeExt(TDEListView::NoSelection);
 
-	m_popup = new KPopupMenu(this, "projectview_popup");
+	m_popup = new TDEPopupMenu(this, "projectview_popup");
 
-	connect(this, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint & )), this,TQT_SLOT(popup(KListView *, TQListViewItem * , const TQPoint & )));
+	connect(this, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint & )), this,TQT_SLOT(popup(TDEListView *, TQListViewItem * , const TQPoint & )));
 
 	connect(this, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotClicked(TQListViewItem*)));
 	setAcceptDrops(true);
@@ -233,7 +233,7 @@ void KileProjectView::slotRun(int id)
 }
 
 //FIXME clean this mess up
-void KileProjectView::popup(KListView *, TQListViewItem *  item, const TQPoint &  point)
+void KileProjectView::popup(TDEListView *, TQListViewItem *  item, const TQPoint &  point)
 {
 	if (item != 0)
 	{
@@ -253,8 +253,8 @@ void KileProjectView::popup(KListView *, TQListViewItem *  item, const TQPoint &
 		{
 			if ( ! isKilePrFile )
 			{
-				KPopupMenu *apps = new KPopupMenu( m_popup);
-				m_offerList = KTrader::self()->query(KMimeType::findByURL(itm->url())->name(), "Type == 'Application'");
+				TDEPopupMenu *apps = new TDEPopupMenu( m_popup);
+				m_offerList = TDETrader::self()->query(KMimeType::findByURL(itm->url())->name(), "Type == 'Application'");
 				for (uint i=0; i < m_offerList.count(); ++i)
 					apps->insertItem(SmallIcon(m_offerList[i]->icon()), m_offerList[i]->name(), i+1);
 
@@ -269,9 +269,9 @@ void KileProjectView::popup(KListView *, TQListViewItem *  item, const TQPoint &
 		if (itm->type() == KileType::File || itm->type() == KileType::ProjectItem)
 		{
 			if ( ! m_ki->isOpen(itm->url()) )
-				m_popup->insertItem(SmallIcon("fileopen"), i18n("&Open"), KPV_ID_OPEN);
+				m_popup->insertItem(SmallIcon("document-open"), i18n("&Open"), KPV_ID_OPEN);
 			else
-				m_popup->insertItem(SmallIcon("filesave"), i18n("&Save"), KPV_ID_SAVE);
+				m_popup->insertItem(SmallIcon("document-save"), i18n("&Save"), KPV_ID_SAVE);
 			insertsep = true;
 		}
 
@@ -325,7 +325,7 @@ void KileProjectView::popup(KListView *, TQListViewItem *  item, const TQPoint &
 		{
 			if ( insertsep )
 				m_popup->insertSeparator();
-			m_popup->insertItem(SmallIcon("fileclose"), i18n("&Close"), KPV_ID_CLOSE);
+			m_popup->insertItem(SmallIcon("window-close"), i18n("&Close"), KPV_ID_CLOSE);
 		}
 
 		m_popup->exec(point);
