@@ -27,8 +27,8 @@
 #include <tqregexp.h>
 #include <tqwhatsthis.h>
 
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include "kiledebug.h"
 
 #include "kileconfig.h"
@@ -39,13 +39,13 @@ namespace KileDialog
 // BEGIN NewLatexCommand
 
 NewLatexCommand::NewLatexCommand(TQWidget *parent, const TQString &caption,
-                                 const TQString &groupname, KListViewItem *lvitem,
+                                 const TQString &groupname, TDEListViewItem *lvitem,
 	                              KileDocument::CmdAttribute cmdtype,
 	                              TQMap<TQString,bool> *dict)
    : KDialogBase( parent,0, true, caption, Ok | Cancel, Ok, true ),
 	  m_dict(dict)
 {
-	// 'add' is only allowed, if the KListViewItem is defined
+	// 'add' is only allowed, if the TDEListViewItem is defined
 	m_addmode = ( lvitem == 0 );
 	m_envmode = ( cmdtype < KileDocument::CmdAttrLabel );
 	m_cmdType = cmdtype;
@@ -300,7 +300,7 @@ void NewLatexCommand::slotOk()
 
 //BEGIN LatexCommandsDialog
 
-LatexCommandsDialog::LatexCommandsDialog(KConfig *config, KileDocument::LatexCommands *commands, TQWidget *parent, const char *name)
+LatexCommandsDialog::LatexCommandsDialog(TDEConfig *config, KileDocument::LatexCommands *commands, TQWidget *parent, const char *name)
    : KDialogBase( parent,name, true, i18n("LaTeX Configuration"), Ok | Cancel | Help, Ok, true ),
 	m_config(config), m_commands(commands)
 {
@@ -316,7 +316,7 @@ LatexCommandsDialog::LatexCommandsDialog(KConfig *config, KileDocument::LatexCom
 
 	// page 1: environment listview
 	TQWidget *page1 = new TQWidget(m_tab);
-	m_lvEnvironments = new KListView(page1);
+	m_lvEnvironments = new TDEListView(page1);
 	m_lvEnvironments->setRootIsDecorated(true);
 	m_lvEnvironments->addColumn(i18n("Environment"));
 	m_lvEnvironments->addColumn(i18n("Starred"));
@@ -336,7 +336,7 @@ LatexCommandsDialog::LatexCommandsDialog(KConfig *config, KileDocument::LatexCom
 
 	// page 2: command listview
 	TQWidget *page2 = new TQWidget(m_tab);
-	m_lvCommands = new KListView(page2);
+	m_lvCommands = new TDEListView(page2);
 	m_lvCommands->setRootIsDecorated(true);
 	m_lvCommands->addColumn(i18n("Command"));
 	m_lvCommands->addColumn(i18n("Starred"));
@@ -409,16 +409,16 @@ void LatexCommandsDialog::resetListviews()
 	m_lvEnvironments->clear();
 	m_lvCommands->clear();
 
-	m_lviAmsmath    = new KListViewItem(m_lvEnvironments,i18n("AMS-Math"));
-	m_lviMath       = new KListViewItem(m_lvEnvironments,i18n("Math"));
-	m_lviList       = new KListViewItem(m_lvEnvironments,i18n("Lists"));
-	m_lviTabular    = new KListViewItem(m_lvEnvironments,i18n("Tabular"));
-	m_lviVerbatim   = new KListViewItem(m_lvEnvironments,i18n("Verbatim"));
+	m_lviAmsmath    = new TDEListViewItem(m_lvEnvironments,i18n("AMS-Math"));
+	m_lviMath       = new TDEListViewItem(m_lvEnvironments,i18n("Math"));
+	m_lviList       = new TDEListViewItem(m_lvEnvironments,i18n("Lists"));
+	m_lviTabular    = new TDEListViewItem(m_lvEnvironments,i18n("Tabular"));
+	m_lviVerbatim   = new TDEListViewItem(m_lvEnvironments,i18n("Verbatim"));
 
-	m_lviLabels     = new KListViewItem(m_lvCommands,i18n("Labels"));
-	m_lviReferences = new KListViewItem(m_lvCommands,i18n("References"));
-	m_lviCitations  = new KListViewItem(m_lvCommands,i18n("Citations"));
-	m_lviInputs	= new KListViewItem(m_lvCommands,i18n("Includes"));
+	m_lviLabels     = new TDEListViewItem(m_lvCommands,i18n("Labels"));
+	m_lviReferences = new TDEListViewItem(m_lvCommands,i18n("References"));
+	m_lviCitations  = new TDEListViewItem(m_lvCommands,i18n("Citations"));
+	m_lviInputs	= new TDEListViewItem(m_lvCommands,i18n("Includes"));
 
 	TQStringList list;
 	TQStringList::ConstIterator it;
@@ -429,7 +429,7 @@ void LatexCommandsDialog::resetListviews()
 	{
 		if ( m_commands->commandAttributes(*it,attr) )
 		{
-			KListViewItem *parent;
+			TDEListViewItem *parent;
 			switch ( attr.type ) {
 				case KileDocument::CmdAttrAmsmath:   parent = m_lviAmsmath;    break;
 				case KileDocument::CmdAttrMath:      parent = m_lviMath;       break;
@@ -452,7 +452,7 @@ LatexCommandsDialog::LVmode LatexCommandsDialog::getListviewMode()
 	return ( m_tab->currentPageIndex() == 0 ) ? lvEnvMode : lvCmdMode;
 }
 
-KileDocument::CmdAttribute LatexCommandsDialog::getCommandMode(KListViewItem *item)
+KileDocument::CmdAttribute LatexCommandsDialog::getCommandMode(TDEListViewItem *item)
 {
 	KileDocument::CmdAttribute type;
 
@@ -480,7 +480,7 @@ KileDocument::CmdAttribute LatexCommandsDialog::getCommandMode(KListViewItem *it
 	return type;
 }
 
-bool LatexCommandsDialog::isParentItem(KListViewItem *item)
+bool LatexCommandsDialog::isParentItem(TDEListViewItem *item)
 {
 	return ( item==m_lviMath       ||
 	         item==m_lviList       ||
@@ -495,14 +495,14 @@ bool LatexCommandsDialog::isParentItem(KListViewItem *item)
 
 ////////////////////////////// entries //////////////////////////////
 
-void LatexCommandsDialog::setEntry(KListViewItem *parent,const TQString &name,
+void LatexCommandsDialog::setEntry(TDEListViewItem *parent,const TQString &name,
 	                                KileDocument::LatexCmdAttributes &attr)
 {
 	// set dictionary
 	m_dictCommands[name] = attr.standard;
 
 	// create an item
-	KListViewItem *item = new KListViewItem(parent,name);
+	TDEListViewItem *item = new TDEListViewItem(parent,name);
 
 	// always set the starred entry
 	if ( attr.starred )
@@ -528,7 +528,7 @@ void LatexCommandsDialog::setEntry(KListViewItem *parent,const TQString &name,
 	}
 }
 
-void LatexCommandsDialog::getEntry(KListViewItem *item,KileDocument::LatexCmdAttributes &attr)
+void LatexCommandsDialog::getEntry(TDEListViewItem *item,KileDocument::LatexCmdAttributes &attr)
 {
 	// always set the starred entry
 	attr.starred = ( item->text(1) == "*" );
@@ -563,7 +563,7 @@ bool LatexCommandsDialog::isUserDefined(const TQString &name)
 
 // look for user defined environment or commands in this listview
 
-bool LatexCommandsDialog::hasUserDefined(KListView *listview)
+bool LatexCommandsDialog::hasUserDefined(TDEListView *listview)
 {
 	for ( TQListViewItem *cur=listview->firstChild(); cur; cur=cur->nextSibling() )
 	{
@@ -590,10 +590,10 @@ void LatexCommandsDialog::slotEnableButtons()
 	bool editState = false;
 	bool resetState = false;
 
-	KListView *listview = ( getListviewMode() == lvEnvMode ) ? m_lvEnvironments : m_lvCommands;
+	TDEListView *listview = ( getListviewMode() == lvEnvMode ) ? m_lvEnvironments : m_lvCommands;
 	resetState = ( hasUserDefined(listview) );
 
-	KListViewItem *item = (KListViewItem *)listview->selectedItem();
+	TDEListViewItem *item = (TDEListViewItem *)listview->selectedItem();
 
 	if ( item && item!=m_lviAmsmath )
 	{
@@ -613,7 +613,7 @@ void LatexCommandsDialog::slotEnableButtons()
 
 void LatexCommandsDialog::slotAddClicked()
 {
-	KListView *listview;
+	TDEListView *listview;
 	TQString caption;
 	bool envmode;
 
@@ -630,7 +630,7 @@ void LatexCommandsDialog::slotAddClicked()
 		envmode  = false;
 	}
 
-	KListViewItem *item = (KListViewItem *)listview->selectedItem();
+	TDEListViewItem *item = (TDEListViewItem *)listview->selectedItem();
 	if ( item && isParentItem(item) )
 	{
 		// get current command type
@@ -651,7 +651,7 @@ void LatexCommandsDialog::slotAddClicked()
 			TQString name;
 			KileDocument::LatexCmdAttributes attr;
 			dialog->getParameter(name,attr);
-			setEntry((KListViewItem *)item,name,attr);
+			setEntry((TDEListViewItem *)item,name,attr);
 			// open this parent item
 			if ( !item->isOpen() )
 			{
@@ -665,7 +665,7 @@ void LatexCommandsDialog::slotAddClicked()
 
 void LatexCommandsDialog::slotDeleteClicked()
 {
-	KListView *listview;
+	TDEListView *listview;
 	TQString message;
 
 	if ( getListviewMode() == lvEnvMode )
@@ -679,7 +679,7 @@ void LatexCommandsDialog::slotDeleteClicked()
 		message  = i18n("Do you want to delete this command?");
 	}
 
-	KListViewItem *item = (KListViewItem *)listview->selectedItem();
+	TDEListViewItem *item = (TDEListViewItem *)listview->selectedItem();
 	if ( item && !isParentItem(item) )
 	{
 		if (KMessageBox::warningContinueCancel(this, message, i18n("Delete"))==KMessageBox::Continue)
@@ -696,7 +696,7 @@ void LatexCommandsDialog::slotDeleteClicked()
 
 void LatexCommandsDialog::slotEditClicked()
 {
-	KListView *listview;
+	TDEListView *listview;
 	TQString caption;
 
 	if ( getListviewMode() == lvEnvMode )
@@ -710,10 +710,10 @@ void LatexCommandsDialog::slotEditClicked()
 		caption  = i18n("LaTeX Commands");
 	}
 
-	KListViewItem *item = (KListViewItem *)listview->selectedItem();
+	TDEListViewItem *item = (TDEListViewItem *)listview->selectedItem();
 	if ( item && !isParentItem(item) )
 	{
-		KListViewItem *parentitem = (KListViewItem *)item->parent();
+		TDEListViewItem *parentitem = (TDEListViewItem *)item->parent();
 		if ( parentitem )
 		{
 			// get current command type
@@ -796,7 +796,7 @@ void LatexCommandsDialog::readConfig()
 	m_cbUserDefined->setChecked( KileConfig::showUserCommands() );
 }
 
-void LatexCommandsDialog::writeConfig(KListView *listview, const TQString &groupname, bool env)
+void LatexCommandsDialog::writeConfig(TDEListView *listview, const TQString &groupname, bool env)
 {
 	// first delete old entries
 	if ( m_config->hasGroup(groupname) )
@@ -813,7 +813,7 @@ void LatexCommandsDialog::writeConfig(KListView *listview, const TQString &group
 	for ( TQListViewItem *cur=listview->firstChild(); cur; cur=cur->nextSibling() )
 	{
 		// get the type of the parent entry
-		attr.type = getCommandMode((KListViewItem *)cur);
+		attr.type = getCommandMode((TDEListViewItem *)cur);
 		if ( attr.type == KileDocument::CmdAttrNone )
 		{
 			KILE_DEBUG() << "\tLatexCommandsDialog error: no parent item (" << cur->text(0) << ")" << endl;
@@ -826,7 +826,7 @@ void LatexCommandsDialog::writeConfig(KListView *listview, const TQString &group
 			TQString key = curchild->text(0);
 			if ( isUserDefined(key) )
 			{
-				getEntry((KListViewItem *)curchild,attr);
+				getEntry((TDEListViewItem *)curchild,attr);
 				TQString value = m_commands->configString(attr,env);
 				KILE_DEBUG() << "\tLatexCommandsDialog write config: " << key << " --> " << value << endl;
 				if ( ! value.isEmpty() )
